@@ -16,6 +16,16 @@ from .pytemplates.caiman_motion_correction_pytemplate import *
 from ...common import get_window_manager
 from ...pyqtgraphCore import LinearRegionItem
 from uuid import UUID
+from copy import deepcopy
+from joblib import Parallel, delayed
+import numpy as np
+from psutil import cpu_count
+import tifffile
+from ...pyqtgraphCore.widgets.MatplotlibWidget import MatplotlibWidget
+import os
+from math import ceil
+from itertools import product
+from typing import *
 
 
 class ModuleGUI(QtWidgets.QDockWidget):
@@ -37,6 +47,15 @@ class ModuleGUI(QtWidgets.QDockWidget):
         self.overlapsH = []
         self.overlapsV = []
 
+        self.ncols_projection_plots = 3
+        self.cmap_projection_plots = 'gray'
+        self.projections_plot_widget = None
+        self.projections_plot_vmin_vmax_stds = 5
+
+        self.currrent_projections: List[np.ndarray] = None
+
+        self.ui.pushButtonViewProjections.clicked.connect(self.view_output_projections)
+
     def draw_quilt(self):
         if self.ui.btnShowQuilt.isChecked() is False:
             self.remove_quilt()
@@ -91,7 +110,11 @@ class ModuleGUI(QtWidgets.QDockWidget):
             gSig = self.ui.spinBoxGSig_filt.value()
             gSig_filt = (gSig, gSig)
 
-        d = {'output_bit_depth': self.ui.comboBoxOutputBitDepth.currentText()}
+        d = \
+            {
+                'output_bit_depth': self.ui.comboBoxOutputBitDepth.currentText(),
+                'template': None
+            }
 
         mc_params = \
             {
@@ -152,7 +175,7 @@ class ModuleGUI(QtWidgets.QDockWidget):
                 raise ValueError(f'Must pass a params dict with the following keys:\n'
                                  f'{required_keys}\n'
                                  f'Please see the docs for more information.')
-            input_params = params
+            input_params = deepcopy(params)
             item_name = input_params['item_name']
 
         input_workEnv = self.vi.viewer.workEnv
@@ -165,3 +188,85 @@ class ModuleGUI(QtWidgets.QDockWidget):
                                    )
 
         return u
+
+    @staticmethod
+    def _get_projection(proj_type: str,  batch_path: str, item_uuid: UUID):
+        tiff_path = os.path.join(batch_path, f'{item_uuid}_mc.tiff')
+        tif = tifffile.TiffFile(tiff_path, is_nih=True)
+        seq = tif.asarray(maxworkers=cpu_count())
+
+        func = getattr(np, f"nan{proj_type}")
+        return func(seq, axis=0)
+
+    def view_output_projections(self):
+        batch_manager = get_window_manager().get_batch_manager()
+        batch_path = batch_manager.batch_path
+
+        items = batch_manager.get_selected_items()  # get a list of indices and UUIDs for the selected items
+        self._projection_item_indices = items[0]
+        item_uuids = items[1]
+
+        if len(self._projection_item_indices) > 3:
+            if QtWidgets.QMessageBox.question(
+                self, 'Many items selected',
+                f"You have selected < {len(self._projection_item_indices)} > items, "
+                f"it may take a while to calculate these projections.\n"
+                f"Do you still want to continue?",
+                QtWidgets.QMessageBox.No,
+                QtWidgets.QMessageBox.Yes
+            ) == QtWidgets.QMessageBox.No:
+                return
+
+        proj = self.ui.comboBoxProjectionsOption.currentText()
+
+        print("Calculating projections, please wait...")
+
+        self.currrent_projections = Parallel(n_jobs=cpu_count(), verbose=5)(
+            delayed(ModuleGUI._get_projection)(proj, batch_path, item_uuid) for item_uuid in item_uuids
+        )
+
+        self.nrows_projection_plots = ceil(len(self._projection_item_indices) / self.ncols_projection_plots)
+
+        self.plot_output_projections()
+
+    def plot_output_projections(self):
+        if self.currrent_projections is None:
+            raise AttributeError("Projections not calculated")
+
+        print("Plotting projections")
+        if self.projections_plot_widget is None:
+            self.projections_plot_widget = MatplotlibWidget()
+        else:
+            self.projections_plot_widget.fig.clear()
+
+        self.projections_plot_widget.axs = self.projections_plot_widget.fig.subplots(self.nrows_projection_plots, self.ncols_projection_plots)
+
+        for i, axes_ix in enumerate(
+                product(range(self.nrows_projection_plots), range(self.ncols_projection_plots))
+        ):
+            if not i < len(self._projection_item_indices):
+                break
+
+            index = self._projection_item_indices[i]
+            projection = self.currrent_projections[i]
+
+            proj_mean = np.nanmean(projection)
+            proj_std = np.nanstd(projection)
+
+            z = self.projections_plot_vmin_vmax_stds * proj_std
+
+            vmin = max(proj_mean - z, np.nanmin(projection))
+            vmax = min(proj_mean + z, np.nanmax(projection))
+
+            self.projections_plot_widget.axs[axes_ix].imshow(
+                projection,
+                cmap=self.cmap_projection_plots,
+                vmin=vmin,
+                vmax=vmax
+            )
+            self.projections_plot_widget.axs[axes_ix].set_title(index)
+            self.projections_plot_widget.axs[axes_ix].set_title(index)
+
+        self.projections_plot_widget.fig.tight_layout()
+        self.projections_plot_widget.draw()
+        self.projections_plot_widget.show()
